summaryrefslogtreecommitdiffstats
path: root/util/mk1mf.pl
diff options
context:
space:
mode:
authorBodo Möller <bodo@openssl.org>1999-07-29 12:57:23 +0000
committerBodo Möller <bodo@openssl.org>1999-07-29 12:57:23 +0000
commit571199434c616deb176a3fff9e5bb05bcc96f53b (patch)
treec95bb3516df3b25b215cb0034d62968680cae495 /util/mk1mf.pl
parent37b7185b5dafec8c1798b2f7ebb3e5c22bf74fa4 (diff)
Always use buildinf.h, which now includes the mk1mfinf.h data.
Using different files caused problems because the dependencies in the Makefiles produced by mk1mf.pl were for the standard case, i.e. mentioned buildinf.h and not mk1mfinf.h.
Diffstat (limited to 'util/mk1mf.pl')
-rwxr-xr-xutil/mk1mf.pl17
1 files changed, 8 insertions, 9 deletions
diff --git a/util/mk1mf.pl b/util/mk1mf.pl
index e4596bebb2..f3f17074f4 100755
--- a/util/mk1mf.pl
+++ b/util/mk1mf.pl
@@ -404,11 +404,11 @@ EOF
my $platform_cpp_symbol = "MK1MF_PLATFORM_$platform";
$platform_cpp_symbol =~ s/-/_/;
-if (open(IN,"crypto/mk1mfinf.h"))
+if (open(IN,"crypto/buildinf.h"))
{
- # Remove entry for this platform in existing file mk1mfinf.h.
+ # Remove entry for this platform in existing file buildinf.h.
- my $old_mk1mfinf_h = "";
+ my $old_buildinf_h = "";
while (<IN>)
{
if (/^\#ifdef $platform_cpp_symbol$/)
@@ -417,21 +417,20 @@ if (open(IN,"crypto/mk1mfinf.h"))
}
else
{
- $old_mk1mfinf_h .= $_;
+ $old_buildinf_h .= $_;
}
}
close(IN);
- open(OUT,">crypto/mk1mfinf.h") || die "Can't open mk1mfinf.h";
- print OUT $old_mk1mfinf_h;
+ open(OUT,">crypto/buildinf.h") || die "Can't open buildinf.h";
+ print OUT $old_buildinf_h;
close(OUT);
}
-open (OUT,">>crypto/mk1mfinf.h") || die "Can't open mk1mfinf.h";
+open (OUT,">>crypto/buildinf.h") || die "Can't open buildinf.h";
printf OUT <<EOF;
#ifdef $platform_cpp_symbol
- /* auto-generated and updated by util/mk1mf.pl for crypto/cversion.c */
- /* (used in place of crypto/buildinf.h by mk1mf builds) */
+ /* auto-generated/updated by util/mk1mf.pl for crypto/cversion.c */
#define CFLAGS "$cc $cflags"
#define PLATFORM "$platform"
EOF